@@ -6,7 +6,7 @@ use warnings;
 
 use Catalyst::Runtime '5.70';
 
-use parent qw/Catalyst/;
+use base qw/Catalyst/;
 
 __PACKAGE__->config( name => 'TestApp' );
 
