@@ -3,7 +3,7 @@ package
 
 use strict;
 use warnings;
-use parent 'Catalyst::Controller';
+use base 'Catalyst::Controller';
 
 __PACKAGE__->config->{namespace} = '';
 
